## Layout


### Explanation of the ideas behind
(1) Cursor moves
One of the major problem people have to deal with is cursor moves.
The idea is to be able to memorize the moves within "space", like the usual
keyboard:
┃       │   ↑   │       ┃
┠───────┼───────┼───────┨
┃   ←   │   ↓   │   →   ┃

The idea is: "very left" = extreme left, "very right" = extreme right. Thus:
┃       │       │   ↑   │       │       ┃
┠───────┼───────┼───────┼───────┼───────┨
┃  ←←←  │   ←   │   ↓   │   →   │  →→→  ┃
(those two keys ←←← and →→→ are Home and End keys)

Diagonals should move a bit further = just one word: like this:
┃       │   ↖   │   ↑   │   ↗   │       ┃
┠───────┼───────┼───────┼───────┼───────┨
┃  ←←←  │   ←   │   ↓   │   →   │  →→→  ┃
(those two keys ↖ and ↗ are key combination Ctrl-Left and Ctrl-Right)

And finally the extreme = move one big "jump" = one page:
┃   ↟   │   ↖   │   ↑   │   ↗   │   ↡   ┃
┠───────┼───────┼───────┼───────┼───────┨
┃  ←←←  │   ←   │   ↓   │   →   │  →→→  ┃
So going to layer 1 with left thumb will give you total cursor moves, and easy
to memorize with the right hand.

(2) Original French layout sucks.
Not optimized and if you're a developper, you have very hard times to reach
special chars like {}, and []. Even () are far from each other.
Thus I've put them all together, very close: opening next to closing, on each
line, this way:
┏━━━━━━━┯━━━━━━━┓
┃   {   │   }   ┃
┠───────┼───────┨
┃   (   │   )   ┃
┠───────┼───────┨
┃   [   │   ]   ┃
┗━━━━━━━━━━━━━━━┛
Layer 2 gives you instant access to those with your left hand

### Keymap 0: Basic layer
```
┏━━━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━━┓   ┏━━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━━━┓
┃   Esc   │  & 1  │  é 2  │  " 3  │  ' 4  │  ( 5  │   ^L3  ┃   ┃  Pscr  │  - 6  │  è 7  │  _ 8  │  ç 9  │  à 0  │  Bspc   ┃
┠─────────┼───────┼───────┼───────┼───────┼───────┼────────┨   ┠────────┼───────┼───────┼───────┼───────┼───────┼─────────┨
┃   Tab   │  a A  │  z Z  │  e E  │  r R  │  t T  │  Bkspc ┃   ┃   +    │  y Y  │  u U  │  i I  │  o O  │  p P  │   ^ ¨   ┃
┠─────────┼───────┼───────┼───────┼───────┼───────┤        ┃   ┠────────┼───────┼───────┼───────┼───────┼───────┼─────────┨
┃    #    │  q Q  │  s S  │  d D  │  f F  │  g G  ├────────┨   ┃        │  h H  │  j J  │  k K  │  l L  │  m M  │ Enter ⏎ ┃
┠─────────┼───────┼───────┼───────┼───────┼───────┤   Del  ┃   ┃   -    ├───────┼───────┼───────┼───────┼───────┼─────────┨
┃ LShft ⇧ │  w W  │  x X  │  c C  │  v V  │  b B  │        ┃   ┃        │  n N  │  , ?  │  ; .  │  : /  │  ! §  │ RShft ⇧ ┃
┗━━━┱─────┴─┬─────┴─┬─────┴─┬─────┴─┬─────┴─┲━━━━━┷━━━━━━━━┛   ┗━━━━━━━━┷━━━━━┱─┴─────┬─┴─────┬─┴─────┬─┴─────┬─┴─────┲━━━┛
    ┃ LCtl  │  LGui │  LAlt │  Bspc │  Del  ┃                                 ┃  Spc  │  RSft │  RAlt │  RGui │  RCtl ┃
    ┗━━━━━━━┷━━━━━━━┷━━━━━━━┷━━━━━━━┷━━━━━━━┛                                 ┗━━━━━━━┷━━━━━━━┷━━━━━━━┷━━━━━━━┷━━━━━━━┛
                                           ┏━━━━━━━┯━━━━━━━┓   ┏━━━━━━━┯━━━━━━━┓
                                           ┃I-Copy │I-Paste┃   ┃  <>   │I-Copy ┃
                                   ┏━━━━━━━╃───────┼───────┨   ┠───────┼───────╄━━━━━━━┓
                                   ┃       │       │ I-Cut ┃   ┃  </>  │       │       ┃
                                   ┃  ~L1  │  ~L2  ├───────┨   ┠───────┤  ~L2  │  ~L1  ┃
                                   ┃       │       │  Del  ┃   ┃  Nbsp │       │       ┃
                                   ┗━━━━━━━┷━━━━━━━┷━━━━━━━┛   ┗━━━━━━━┷━━━━━━━┷━━━━━━━┛
```
* Layers 1 and 2 are accessible using either right or left
* When you want to move the cursor, press with right ~L1 and with the left
  you move the cursor
* When you develop, press with left ~L1 and with the right you have access to
  almost all the symbols developpers use
* There are macros for Web developpers: opening tag, closing tag and &amp;nbsp;
  accessible with the right hand

### Keymap 1: Left hand = chars for developper, right hand = moving cursor + cut/copy/paste
```
┏━━━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━━┓   ┏━━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━━━┓
┃   Esc   │   f①  │   f②  │   f③  │   f④  │   f⑤  │   f⑥   ┃   ┃   f⑦   │   f⑧  │   f⑨  │  f⑩   │  f⑪   │  f⑫   │  Bspc   ┃
┠─────────┼───────┼───────┼───────┼───────┼───────┼────────┨   ┠────────┼───────┼───────┼───────┼───────┼───────┼─────────┨
┃   Tab   │   \   │   *   │   $   │   {   │   }   │   ~    ┃   ┃  Sign. │ PgUp ↟│  (↖)  │   ↑   │  (↗)  │ ↡ PgDn│   ^ ¨   ┃
┠─────────┼───────┼───────┼───────┼───────┼───────┤        ┃   ┠────────┼───────┼───────┼───────┼───────┼───────┼─────────┨
┃    #    │   =   │   |   │   /   │   (   │   )   ├────────┨   ┃        │Home←← │   ←   │   ↓   │   →   │ →→ End│ Enter ⏎ ┃
┠─────────┼───────┼───────┼───────┼───────┼───────┤   Del  ┃   ┃   -    ├───────┼───────┼───────┼───────┼───────┼─────────┨
┃ LShft ⇧ │   <   │   @   │   >   │   [   │   ]   │        ┃   ┃        │  n N  │ I-Copy│  Ins  │ PgDn  │I-Paste│ RShft ⇧ ┃
┗━━━┱─────┴─┬─────┴─┬─────┴─┬─────┴─┬─────┴─┲━━━━━┷━━━━━━━━┛   ┗━━━━━━━━┷━━━━━┱─┴─────┬─┴─────┬─┴─────┬─┴─────┬─┴─────┲━━━┛
    ┃ LCtl  │  LGui │  LAlt │  Bspc │  Del  ┃                                 ┃  Spc  │  RSft │  RAlt │  RGui │  RCtl ┃
    ┗━━━━━━━┷━━━━━━━┷━━━━━━━┷━━━━━━━┷━━━━━━━┛                                 ┗━━━━━━━┷━━━━━━━┷━━━━━━━┷━━━━━━━┷━━━━━━━┛
                                           ┏━━━━━━━┯━━━━━━━┓   ┏━━━━━━━┯━━━━━━━┓
                                           ┃I-Copy │I-Paste┃   ┃  <>   │I-Copy ┃
                                   ┏━━━━━━━╃───────┼───────┨   ┠───────┼───────╄━━━━━━━┓
                                   ┃       │       │ I-Cut ┃   ┃  </>  │       │       ┃
                                   ┃  ~L1  │  ~L2  ├───────┨   ┠───────┤  ~L2  │  ~L1  ┃
                                   ┃       │       │  Del  ┃   ┃  Nbsp │       │       ┃
                                   ┗━━━━━━━┷━━━━━━━┷━━━━━━━┛   ┗━━━━━━━┷━━━━━━━┷━━━━━━━┛
```
* Sign. means macro signature = write "Olivier Pons / HQF Development"
* Right hand: cursor move
* (↖) and (↗)  are key combination Ctrl-Left and Ctrl-Right

### Keymap 2: Left hand = french accents, right hand = keypad and caps / num lock
```
┏━━━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━━┓   ┏━━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━━━┓
┃    -    │   -   │   -   │   -   │   -   │   -   │   -    ┃   ┃  CAPS  │  NLCK │  NLCK │   /   │   *   │  P-   │  Bspc   ┃
┠─────────┼───────┼───────┼───────┼───────┼───────┼────────┨   ┠────────┼───────┼───────┼───────┼───────┼───────┼─────────┨
┃    -    │   â   │   ê   │   î   │   ô   │   û   │   ~    ┃   ┃  Sign. │ Copy  │  P7   │  P8   │  P9   │  P+   │   ^ ¨   ┃
┠─────────┼───────┼───────┼───────┼───────┼───────┤        ┃   ┠────────┼───────┼───────┼───────┼───────┼───────┼─────────┨
┃    -    │   -   │   -   │   -   │   -   │   ù   ├────────┨   ┃        │ Home  │  P4   │  P5   │  P6   │  P+   │ PEnter⏎ ┃
┠─────────┼───────┼───────┼───────┼───────┼───────┤   `    ┃   ┃   -    ├───────┼───────┼───────┼───────┼───────┼─────────┨
┃    -    │   -   │   -   │   -   │   -   │   -   │        ┃   ┃        │   -   │  P1   │  P2   │  P3   │ PEnt  │ RShft ⇧ ┃
┗━━━┱─────┴─┬─────┴─┬─────┴─┬─────┴─┬─────┴─┲━━━━━┷━━━━━━━━┛   ┗━━━━━━━━┷━━━━━┱─┴─────┬─┴─────┬─┴─────┬─┴─────┬─┴─────┲━━━┛
    ┃   -   │   -   │   -   │   -   │   -   ┃                                 ┃  P0   │   .   │  RAlt │  RGui │  RCtl ┃
    ┗━━━━━━━┷━━━━━━━┷━━━━━━━┷━━━━━━━┷━━━━━━━┛                                 ┗━━━━━━━┷━━━━━━━┷━━━━━━━┷━━━━━━━┷━━━━━━━┛
                                           ┏━━━━━━━┯━━━━━━━┓   ┏━━━━━━━┯━━━━━━━┓
                                           ┃C-Copy │C-Paste┃   ┃  <>   │I-Copy ┃
                                   ┏━━━━━━━╃───────┼───────┨   ┠───────┼───────╄━━━━━━━┓
                                   ┃       │       │ C-Cut ┃   ┃  </>  │       │       ┃
                                   ┃  ~L1  │  ~L2  ├───────┨   ┠───────┤  ~L2  │  ~L1  ┃
                                   ┃       │       │  Del  ┃   ┃  Nbsp │       │       ┃
                                   ┗━━━━━━━┷━━━━━━━┷━━━━━━━┛   ┗━━━━━━━┷━━━━━━━┷━━━━━━━┛
```
* Sign. means macro signature = write "Olivier Pons / HQF Development"
* NB: Layer 1: I-Copy = Ctrl-Ins, I-Paste = Shift-Ins, C-Cut = Ctrl-Del
* NB: Layer 2: C-Copy = Ctrl-C, C-Paste = Ctrl-V, C-Cut = Ctrl-X

### Keymap 3: QWERTY
No need to show the QWERTY: it's the same as layer 0 but 4 letters are swapped.


### Many thanks!
* Wikipedia https://en.wikipedia.org/wiki/Box_Drawing
* QMK Firmware creators and maintainers

