#include QMK_KEYBOARD_H
#include "debug.h"
#include "action_layer.h"

#define L_0 0 // default layer
#define L_1 1 // code chars | move layer
#define L_2 2 // accents    | keypad layer
#define L_3 3 // QWERTY for games where you cant change the layout
#define L_4 4 // League of Legends premade sentences
#define L_5 5 // League of Legends Alt Remap

#define CAPS_CTL CTL_T(KC_CAPS) // Caps on tap, Ctrl on hold.

#define C_COPY   LCTL(KC_C) // LCtrl-c Copy
#define C_CUT    LCTL(KC_X) // LCtrl-x Cut
#define C_PASTE  LCTL(KC_V) // LCtrl-v Paste
#define I_COPY   LCTL(KC_INS) // Ctrl  - Ins   Copy
#define I_CUT    LSFT(KC_DEL) // Shift - Suppr Cut
#define I_PASTE  LSFT(KC_INS) // Shift - Ins   Paste

#define I_PCT    LSFT(KC_QUOT) // % Percent

#define C_LEFT   LCTL(KC_LEFT)  // Ctrl  - ←
#define C_RIGHT  LCTL(KC_RIGHT) // Ctrl  - →
#define C_HTG    RALT(KC_3) // # Hashtag

#define X_LT LCA(KC_LEFT)  // LCtrl - LAlt - ←
#define X_RT LCA(KC_RIGHT) // LCtrl - LAlt - →
#define X_MX LCA(KC_UP)    // LCtrl - LAlt - →
// I've defined this shortcut to maximize the current window:
#define X_SB LCA(KC_B)     // LCtrl - LAlt - B

#define _OTG   1 // <>
#define _CTG   2 // </>
#define _ATG   3 // <></>
#define _NBSP  4 // </>
#define _HQF   5 // Signature: "Olivier Pons / Django Expert / HQF Development"
#define _HQF2  6 // Signature: "Olivier Pons / ..." + site Web a la fin
#define _MAIL  7 // email: olivier.pons@gmail.com
#define _GT    8 // >  Greater than
#define _PPE   9 // |  Pipe
#define _BKS  10 // \\ Backslash
#define _LBK  11 // { Left bracket
#define _RBK  12 // { Right bracket
#define _SLH  13 // / Slash
#define _HTG  14 // # Hashtag
#define _OSB  17 // [ Opening Square bracket
#define _CSB  18 // ] Closing Square bracket
#define _ARB  19 // @ Arobase
#define _TLD  20 // ~ Tilde
#define _BQT  21 // ` Backquote
#define _C_A  22 // â
#define _C_E  23 // ê
#define _C_I  24 // î
#define _C_O  25 // ô
#define _C_U  26 // û
#define _XLT  27 // LCtrl - LAlt - ←
#define _XRT  28 // LCtrl - LAlt - →

#define _L_0 29 // gg wp
#define _L_1 30 // gg wp!
#define _L_2 31 // sry i'm bad
#define _L_3 32 // sry i'm very very bad
#define _L_4 33 // sry i'm trying my best
#define _L_5 34 // /mute all
#define _L_6 35 // please stop insult
#define _L_7 36 // sry i'm trying my best
#define _L_8 37 // be patient
#define _L_9 38 // we'll win in the end
#define _L10 39 // gj!
#define _L11 40 // wp!
#define _L12 41 // gj wp!
#define _L13 42 // wow! you're amazing! best player ever!
#define _L14 43 // you're so kind to play with me! thanks again!
#define _L15 44 // mb sry...
#define _L16 45 // it's my fault sry
#define _L17 46 // i'm so sorry...
#define _L18 47 // i'm so sorry...
#define _L19 48 // i'm so sorry...

// Special KEYMAPPING for easy readability:
#define ERGODOX_KEYMAP( \
  L01,L02,L03,L04,L05,L06,L07,    R01,R02,R03,R04,R05,R06,R07, \
  L08,L09,L10,L11,L12,L13,L14,    R08,R09,R10,R11,R12,R13,R14, \
  L15,L16,L17,L18,L19,L20,            R15,R16,R17,R18,R19,R20, \
  L21,L22,L23,L24,L25,L26,L27,    R21,R22,R23,R24,R25,R26,R27, \
  L28,L29,L30,L31,L32,                    R28,R29,R30,R31,R32, \
                       L33,L34,   R33,R34, \
                           L35,   R35, \
                   L36,L37,L38,   R36,R37,R38 \
  ) \
  LAYOUT_ergodox( \
      (L01),(L02),(L03),(L04),(L05),(L06),(L07),(L08),(L09),(L10),(L11) , \
      (L12),(L13),(L14),(L15),(L16),(L17),(L18),(L19),(L20),(L21),(L22) , \
      (L23),(L24),(L25),(L26),(L27),(L28),(L29),(L30),(L31),(L32),(L33) , \
      (L34),(L35),(L36),(L37),(L38),(R01),(R02),(R03),(R04),(R05),(R06) , \
      (R07),(R08),(R09),(R10),(R11),(R12),(R13),(R14),(R15),(R16),(R17) , \
      (R18),(R19),(R20),(R21),(R22),(R23),(R24),(R25),(R26),(R27),(R28) , \
      (R29),(R30),(R31),(R32),(R33),(R34),(R35),(R36),(R37),(R38) \
  )

// NOTE: Cells marked with ACCESS must remain transparent, they're the keys that actually get to that layer


const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
[L_0] = ERGODOX_KEYMAP( // Layer 0 :
  /* ┏━━━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━━┓   ┏━━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━━━┓ */
  /* ┃   Esc   │  & 1  │  é 2  │  " 3  │  ' 4  │  ( 5  │   ^L3  ┃   ┃  Pscr  │  - 6  │  è 7  │  _ 8  │  ç 9  │  à 0  │  Bspc   ┃ */
       KC_ESC  , KC_1  , KC_2  , KC_3  , KC_4  , KC_5  , TO(L_3),    KC_PSCR , KC_6  , KC_7  , KC_8  , KC_9  , KC_0  , KC_BSPC ,
  /* ┠─────────┼───────┼───────┼───────┼───────┼───────┼────────┨   ┠────────┼───────┼───────┼───────┼───────┼───────┼─────────┨ */
  /* ┃   Tab   │  a A  │  z Z  │  e E  │  r R  │  t T  │  Bkspc ┃   ┃   +    │  y Y  │  u U  │  i I  │  o O  │  p P  │   ^ ¨   ┃ */
       KC_TAB  , KC_Q  , KC_W  , KC_E  , KC_R  , KC_T  , KC_BSPC,    KC_PPLS , KC_Y  , KC_U  , KC_I  , KC_O  , KC_P  , KC_LBRC ,
  /* ┠─────────┼───────┼───────┼───────┼───────┼───────┤        ┃   ┠────────┼───────┼───────┼───────┼───────┼───────┼─────────┨ */
  /* ┃    #    │  q Q  │  s S  │  d D  │  f F  │  g G  ├────────┨   ┃        │  h H  │  j J  │  k K  │  l L  │  m M  │ Enter ⏎ ┃ */
        C_HTG  , KC_A  , KC_S  , KC_D  , KC_F  , KC_G  ,                       KC_H  , KC_J  , KC_K  , KC_L  ,KC_SCLN, KC_ENT  ,
  /* ┠─────────┼───────┼───────┼───────┼───────┼───────┤   Del  ┃   ┃   -    ├───────┼───────┼───────┼───────┼───────┼─────────┨ */
  /* ┃ LShft ⇧ │  w W  │  x X  │  c C  │  v V  │  b B  │        ┃   ┃        │  n N  │  , ?  │  ; .  │  : /  │  ! §  │ RShft ⇧ ┃ */
       KC_LSFT , KC_Z  , KC_X  , KC_C  , KC_V  , KC_B  , KC_DEL ,    KC_PMNS , KC_N  , KC_M  ,KC_COMM,KC_DOT ,KC_SLASH, KC_RSFT ,
  /* ┗━━━┱─────┴─┬─────┴─┬─────┴─┬─────┴─┬─────┴─┲━━━━━┷━━━━━━━━┛   ┗━━━━━━━━┷━━━━━┱─┴─────┬─┴─────┬─┴─────┬─┴─────┬─┴─────┲━━━┛ */
  /*     ┃ LCtl  │  LGui │  LAlt │  Bspc │  Del  ┃                                 ┃  Spc  │  RSft │  RAlt │  RGui │  RCtl ┃     */
          KC_LCTL,KC_LGUI,KC_LALT,KC_BSPC,KC_DEL ,                                  KC_SPC ,KC_RSFT,KC_RALT,KC_RGUI,KC_RCTL,
  /*     ┗━━━━━━━┷━━━━━━━┷━━━━━━━┷━━━━━━━┷━━━━━━━┛                                 ┗━━━━━━━┷━━━━━━━┷━━━━━━━┷━━━━━━━┷━━━━━━━┛     */
  /*                                            ┏━━━━━━━┯━━━━━━━┓   ┏━━━━━━━┯━━━━━━━┓                                            */
  /*                                            ┃I-Copy │I-Paste┃   ┃  <>   │ <> </>┃                                            */
                                               I_COPY  ,I_PASTE ,    M(_OTG),M(_ATG),
  /*                                    ┏━━━━━━━╃───────┼───────┨   ┠───────┼───────╄━━━━━━━┓                                    */
  /*                                    ┃       │       │ I-Cut ┃   ┃  </>  │       │       ┃                                    */
                                                          I_CUT ,    M(_CTG),
  /*                                    ┃  ~L1  │  ~L2  ├───────┨   ┠───────┤  ~L2  │  ~L1  ┃                                    */
  /*                                    ┃       │       │  Del  ┃   ┃  Nbsp │       │       ┃                                    */
                                         MO(L_1),MO(L_2),KC_DEL ,   M(_NBSP),MO(L_2),MO(L_1)
  /*                                    ┗━━━━━━━┷━━━━━━━┷━━━━━━━┛   ┗━━━━━━━┷━━━━━━━┷━━━━━━━┛                                    */
  ),

[L_1] = ERGODOX_KEYMAP( // Layer 1
  /* Left hand = chars for developper                               Right hand = moving cursor + cut/copy/paste                  */
  /* ┏━━━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━━┓   ┏━━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━━━┓ */
  /* ┃   Esc   │   f①  │   f②  │   f③  │   f④  │   f⑤  │   f⑥   ┃   ┃   f⑦   │   f⑧  │   f⑨  │  f⑩   │  f⑪   │  f⑫   │  Bspc   ┃ */
       KC_TRNS , KC_F1 , KC_F2 , KC_F3 , KC_F4 , KC_F5 ,  KC_F6 ,     KC_F7  , KC_F8 , KC_F9 , KC_F10, KC_F11, KC_F12, KC_TRNS ,
  /* ┠─────────┼───────┼───────┼───────┼───────┼───────┼────────┨   ┠────────┼───────┼───────┼───────┼───────┼───────┼─────────┨ */
  /* ┃   Tab   │   \   │   *   │   $   │   {   │   }   │   ~    ┃   ┃  Sign. │ PgUp  │Ctrl ← │   ↑   │Ctrl → │ PgDn  │   ^ ¨   ┃ */
       KC_TRNS ,M(_BKS),KC_BSLS,KC_RBRC,M(_LBK),M(_RBK), M(_TLD),     M(_HQF),KC_PGUP,C_LEFT , KC_UP ,C_RIGHT,KC_PGDN, KC_LBRC ,
  /* ┠─────────┼───────┼───────┼───────┼───────┼───────┤        ┃   ┠────────┼───────┼───────┼───────┼───────┼───────┼─────────┨ */
  /* ┃    #    │   =   │   |   │   /   │   (   │   )   ├────────┨   ┃        │  Home │   ←   │   ↓   │   →   │  End  │ Enter ⏎ ┃ */
       KC_TRNS ,KC_EQL ,M(_PPE),M(_SLH), KC_5  ,KC_MINS,                      KC_HOME,KC_LEFT,KC_DOWN,KC_RGHT,KC_END , KC_PENT ,
  /* ┠─────────┼───────┼───────┼───────┼───────┼───────┤   Del  ┃   ┃   -    ├───────┼───────┼───────┼───────┼───────┼─────────┨ */
  /* ┃ LShft ⇧ │   <   │   @   │   >   │   [   │   ]   │        ┃   ┃        │  n N  │ I-Copy│  Ins  │ PgDn  │I-Paste│ RShft ⇧ ┃ */
       KC_TRNS ,KC_NUBS,M(_ARB),M(_GT) ,M(_OSB),M(_CSB), I_PCT  ,    M(_MAIL),KC_TRNS, I_COPY,KC_INS ,KC_PGDN,I_PASTE, KC_TRNS ,
  /* ┗━━━┱─────┴─┬─────┴─┬─────┴─┬─────┴─┬─────┴─┲━━━━━┷━━━━━━━━┛   ┗━━━━━━━━┷━━━━━┱─┴─────┬─┴─────┬─┴─────┬─┴─────┬─┴─────┲━━━┛ */
  /*     ┃ LCtl  │  LGui │  LAlt │  Bspc │  Del  ┃                                 ┃  Spc  │   .   │  RAlt │  RGui │  RCtl ┃     */
          KC_TRNS,KC_TRNS,KC_TRNS,KC_TRNS,KC_TRNS,                                  KC_TRNS,KC_PDOT,KC_TRNS,KC_TRNS,KC_TRNS,
  /*     ┗━━━━━━━┷━━━━━━━┷━━━━━━━┷━━━━━━━┷━━━━━━━┛                                 ┗━━━━━━━┷━━━━━━━┷━━━━━━━┷━━━━━━━┷━━━━━━━┛     */
  /*                                            ┏━━━━━━━┯━━━━━━━┓   ┏━━━━━━━┯━━━━━━━┓                                            */
  /*                                            ┃I-Copy │I-Paste┃   ┃  <>   │I-Copy ┃                                            */
                                                 I_COPY ,I_PASTE,    KC_TRNS,KC_TRNS,
  /*                                    ┏━━━━━━━╃───────┼───────┨   ┠───────┼───────╄━━━━━━━┓                                    */
  /*                                    ┃       │       │ I-Cut ┃   ┃  </>  │       │       ┃                                    */
                                                          I_CUT ,    KC_TRNS,
  /*                                    ┃  ~L1  │  ~L2  ├───────┨   ┠───────┤  ~L2  │  ~L1  ┃                                    */
  /*                                    ┃       │       │  Del  ┃   ┃  Nbsp │       │       ┃                                    */
                                         KC_TRNS,KC_TRNS,KC_TRNS,    KC_TRNS,KC_TRNS,KC_TRNS
  /*                                    ┗━━━━━━━┷━━━━━━━┷━━━━━━━┛   ┗━━━━━━━┷━━━━━━━┷━━━━━━━┛                                    */
  ),

[L_2] = ERGODOX_KEYMAP( // Layer 2
  /* Left hand = accents                                             Right hand = keypad and caps / num lock                     */
  /* ┏━━━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━━┓   ┏━━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━━━┓ */
  /* ┃    -    │   -   │   -   │   -   │   -   │   -   │   -    ┃   ┃  CAPS  │  NLCK │  NLCK │   /   │   *   │  P-   │  Bspc   ┃ */
       KC_TRNS ,KC_TRNS,KC_TRNS,KC_TRNS,KC_TRNS,KC_TRNS, KC_TRNS,    KC_CAPS ,KC_NLCK,KC_NLCK,KC_PSLS,KC_PAST,KC_PMNS, KC_TRNS ,
  /* ┠─────────┼───────┼───────┼───────┼───────┼───────┼────────┨   ┠────────┼───────┼───────┼───────┼───────┼───────┼─────────┨ */
  /* ┃    -    │   -   │   -   │CtAlt↑ │   û   │   ù   │   ~    ┃   ┃  Sign. │ Copy  │  P7   │  P8   │  P9   │  P+   │   ^ ¨   ┃ */
       KC_TRNS ,KC_TRNS,KC_TRNS, X_MX  ,M(_C_U),KC_QUOT, M(_TLD),    M(_HQF2),KC_TRNS, KC_P7 , KC_P8 , KC_P9 ,KC_PPLS, KC_TRNS ,
  /* ┠─────────┼───────┼───────┼───────┼───────┼───────┤        ┃   ┠────────┼───────┼───────┼───────┼───────┼───────┼─────────┨ */
  /* ┃    -    │   -   │CtAlt← │CtAltB │CtAlt→ │   ù   ├────────┨   ┃        │ Home  │  P4   │  P5   │  P6   │  P+   │ PEnter⏎ ┃ */
       KC_TRNS ,KC_TRNS, X_LT  , X_SB  , X_RT  ,KC_QUOT,                      KC_HOME, KC_P4 , KC_P5 , KC_P6 ,KC_PPLS, KC_TRNS ,
  /* ┠─────────┼───────┼───────┼───────┼───────┼───────┤   ù    ┃   ┃   -    ├───────┼───────┼───────┼───────┼───────┼─────────┨ */
  /* ┃    -    │   â   │   ê   │   î   │   ô   │   `   │        ┃   ┃        │   -   │  P1   │  P2   │  P3   │ PEnt  │ RShft ⇧ ┃ */
       KC_TRNS ,M(_C_A),M(_C_E),M(_C_I),M(_C_O),M(_BQT), KC_QUOT,    M(_MAIL),KC_TRNS, KC_P1 , KC_P2 , KC_P3 ,KC_PENT, KC_TRNS ,
  /* ┗━━━┱─────┴─┬─────┴─┬─────┴─┬─────┴─┬─────┴─┲━━━━━┷━━━━━━━━┛   ┗━━━━━━━━┷━━━━━┱─┴─────┬─┴─────┬─┴─────┬─┴─────┬─┴─────┲━━━┛ */
  /*     ┃ LCtl  │  LGui │  LAlt │  Bspc │  Del  ┃                                 ┃  P0   │   .   │  RAlt │  RGui │  RCtl ┃     */
          KC_TRNS,KC_TRNS,KC_TRNS,KC_TRNS,KC_TRNS,                                   KC_P0 ,KC_PDOT,KC_TRNS,KC_TRNS,KC_TRNS,
  /*     ┗━━━━━━━┷━━━━━━━┷━━━━━━━┷━━━━━━━┷━━━━━━━┛                                 ┗━━━━━━━┷━━━━━━━┷━━━━━━━┷━━━━━━━┷━━━━━━━┛     */
  /*                                            ┏━━━━━━━┯━━━━━━━┓   ┏━━━━━━━┯━━━━━━━┓                                            */
  /*                                            ┃C-Copy │C-Paste┃   ┃  <>   │I-Copy ┃                                            */
                                                 C_COPY ,C_PASTE,    KC_TRNS,KC_TRNS,
  /*                                    ┏━━━━━━━╃───────┼───────┨   ┠───────┼───────╄━━━━━━━┓                                    */
  /*                                    ┃       │       │ C-Cut ┃   ┃  </>  │       │       ┃                                    */
                                                          C_CUT ,    KC_TRNS,
  /*                                    ┃  ~L1  │  ~L2  ├───────┨   ┠───────┤  ~L2  │  ~L1  ┃                                    */
  /*                                    ┃       │       │  Del  ┃   ┃  Nbsp │       │       ┃                                    */
                                         KC_TRNS,KC_TRNS,KC_TRNS,    KC_TRNS,KC_TRNS,KC_TRNS
  /*                                    ┗━━━━━━━┷━━━━━━━┷━━━━━━━┛   ┗━━━━━━━┷━━━━━━━┷━━━━━━━┛                                    */
  ),
[L_3] = ERGODOX_KEYMAP( // Layer 3
  /* Same as layer 0 but QWERTY for games where you cant change the layout                                                       */
  /* ┏━━━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━━┓   ┏━━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━━━┓ */
  /* ┃   Esc   │  & 1  │  é 2  │  " 3  │  ' 4  │  ( 5  │   ^L4  ┃   ┃  Pscr  │  - 6  │  è 7  │  _ 8  │  ç 9  │  à 0  │  Bspc   ┃ */
       KC_ESC  , KC_1  , KC_2  , KC_3  , KC_4  , KC_5  , TO(L_4),    KC_PSCR , KC_6  , KC_7  , KC_8  , KC_9  , KC_0  , KC_BSPC ,
  /* ┠─────────┼───────┼───────┼───────┼───────┼───────┼────────┨   ┠────────┼───────┼───────┼───────┼───────┼───────┼─────────┨ */
  /* ┃   Tab   │  q Q  │  w W  │  e E  │  r R  │  t T  │  Bkspc ┃   ┃   +    │  y Y  │  u U  │  i I  │  o O  │  p P  │   ^ ¨   ┃ */
       KC_TAB  , KC_A  , KC_Z  , KC_E  , KC_R  , KC_T  , KC_BSPC,    KC_PPLS , KC_Y  , KC_U  , KC_I  , KC_O  , KC_P  , KC_LBRC ,
  /* ┠─────────┼───────┼───────┼───────┼───────┼───────┤        ┃   ┠────────┼───────┼───────┼───────┼───────┼───────┼─────────┨ */
  /* ┃    #    │  a A  │  s S  │  d D  │  f F  │  g G  ├────────┨   ┃        │  h H  │  j J  │  k K  │  l L  │  m M  │ Enter ⏎ ┃ */
        C_HTG  , KC_Q  , KC_S  , KC_D  , KC_F  , KC_G  ,                       KC_H  , KC_J  , KC_K  , KC_L  ,KC_SCLN, KC_ENT  ,
  /* ┠─────────┼───────┼───────┼───────┼───────┼───────┤   Del  ┃   ┃   -    ├───────┼───────┼───────┼───────┼───────┼─────────┨ */
  /* ┃ LShft ⇧ │  z Z  │  x X  │  c C  │  v V  │  b B  │        ┃   ┃        │  n N  │  , ?  │  ; .  │  : /  │  ! §  │ RShft ⇧ ┃ */
       KC_LSFT , KC_W  , KC_X  , KC_C  , KC_V  , KC_B  , KC_DEL ,    KC_PMNS , KC_N  , KC_M  ,KC_COMM,KC_DOT ,KC_SLASH, KC_RSFT ,
  /* ┗━━━┱─────┴─┬─────┴─┬─────┴─┬─────┴─┬─────┴─┲━━━━━┷━━━━━━━━┛   ┗━━━━━━━━┷━━━━━┱─┴─────┬─┴─────┬─┴─────┬─┴─────┬─┴─────┲━━━┛ */
  /*     ┃ LCtl  │  LGui │  LAlt │  Bspc │  Del  ┃                                 ┃  Spc  │  RSft │  RAlt │  RGui │  RCtl ┃     */
          KC_LCTL,KC_LGUI,KC_LALT,KC_BSPC,KC_DEL ,                                  KC_SPC ,KC_RSFT,KC_RALT,KC_RGUI,KC_RCTL,
  /*     ┗━━━━━━━┷━━━━━━━┷━━━━━━━┷━━━━━━━┷━━━━━━━┛                                 ┗━━━━━━━┷━━━━━━━┷━━━━━━━┷━━━━━━━┷━━━━━━━┛     */
  /*                                            ┏━━━━━━━┯━━━━━━━┓   ┏━━━━━━━┯━━━━━━━┓                                            */
  /*                                            ┃I-Copy │I-Paste┃   ┃  <>   │  ^L0  ┃                                            */
                                                 I_COPY ,I_PASTE,    M(_OTG),TO(L_0),
  /*                                    ┏━━━━━━━╃───────┼───────┨   ┠───────┼───────╄━━━━━━━┓                                    */
  /*                                    ┃       │       │ I-Cut ┃   ┃  </>  │       │       ┃                                    */
                                                          I_CUT ,    M(_CTG),
  /*                                    ┃  ~L1  │  ~L2  ├───────┨   ┠───────┤  ~L2  │  ~L1  ┃                                    */
  /*                                    ┃       │       │  Del  ┃   ┃  Nbsp │       │       ┃                                    */
                                         MO(L_1),MO(L_2),KC_DEL ,   M(_NBSP),MO(L_2),MO(L_1)
  /*                                    ┗━━━━━━━┷━━━━━━━┷━━━━━━━┛   ┗━━━━━━━┷━━━━━━━┷━━━━━━━┛                                    */
  ),
[L_4] = ERGODOX_KEYMAP( // Layer 4
  /* ┏━━━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━━┓   ┏━━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━━━┓ */
  /* ┃    -    │   -   │   -   │   -   │   -   │   -   │   ^L5  ┃   ┃   -    │   -   │   -   │   -   │   -   │   -   │    -    ┃ */
       KC_TRNS ,KC_TRNS,KC_TRNS,KC_TRNS,KC_TRNS,KC_TRNS, TO(L_5),    KC_TRNS ,KC_TRNS,KC_TRNS,KC_TRNS,KC_TRNS,KC_TRNS, KC_TRNS ,
  /* ┠─────────┼───────┼───────┼───────┼───────┼───────┼────────┨   ┠────────┼───────┼───────┼───────┼───────┼───────┼─────────┨ */
  /* ┃    -    │ gg wp │ gj !  │  sry  │  bad  │ vvbad │   -    ┃   ┃   -    │   -   │stopins│tryingm│be pati│we'll w│    -    ┃ */
       KC_TRNS ,M(_L_0),M(_L_1),M(_L_2),M(_L_3),M(_L_4), KC_TRNS,    KC_TRNS ,M(_L_5),M(_L_6),M(_L_7),M(_L_8),M(_L_9), KC_TRNS ,
  /* ┠─────────┼───────┼───────┼───────┼───────┼───────┤        ┃   ┠────────┼───────┼───────┼───────┼───────┼───────┼─────────┨ */
  /* ┃    -    │   -   │   -   │   -   │   -   │   -   ├────────┨   ┃        │   -   │   -   │   -   │   -   │   -   │    -    ┃ */
       KC_TRNS ,KC_TRNS,KC_TRNS,KC_TRNS,KC_TRNS,KC_TRNS,                      KC_TRNS,KC_TRNS,KC_TRNS,KC_TRNS,KC_TRNS, KC_TRNS ,
  /* ┠─────────┼───────┼───────┼───────┼───────┼───────┤   -    ┃   ┃   -    ├───────┼───────┼───────┼───────┼───────┼─────────┨ */
  /* ┃    -    │   -   │   -   │   -   │   -   │   -   │        ┃   ┃        │   -   │   -   │   -   │   -   │   -   │    -    ┃ */
       KC_TRNS ,M(_L10),M(_L11),M(_L12),M(_L13),M(_L14),KC_TRNS ,    KC_TRNS ,M(_L15),M(_L16),M(_L17),M(_L18),M(_L19), KC_TRNS ,
  /* ┗━━━┱─────┴─┬─────┴─┬─────┴─┬─────┴─┬─────┴─┲━━━━━┷━━━━━━━━┛   ┗━━━━━━━━┷━━━━━┱─┴─────┬─┴─────┬─┴─────┬─┴─────┬─┴─────┲━━━┛ */
  /*     ┃   -   │   -   │   -   │   -   │   -   ┃                                 ┃   -   │   -   │   -   │   -   │   -   ┃     */
          KC_TRNS,KC_TRNS,KC_TRNS,KC_TRNS,KC_TRNS,                                  KC_TRNS,KC_TRNS,KC_TRNS,KC_TRNS,KC_TRNS,
  /*     ┗━━━━━━━┷━━━━━━━┷━━━━━━━┷━━━━━━━┷━━━━━━━┛                                 ┗━━━━━━━┷━━━━━━━┷━━━━━━━┷━━━━━━━┷━━━━━━━┛     */
  /*                                            ┏━━━━━━━┯━━━━━━━┓   ┏━━━━━━━┯━━━━━━━┓                                            */
  /*                                            ┃I-Copy │I-Paste┃   ┃  <>   │  ^L0  ┃                                            */
                                                 M(_OTG),I_PASTE,    M(_OTG),TO(L_0),
  /*                                    ┏━━━━━━━╃───────┼───────┨   ┠───────┼───────╄━━━━━━━┓                                    */
  /*                                    ┃       │       │ I-Cut ┃   ┃  </>  │       │       ┃                                    */
                                                          I_CUT ,    M(_CTG),
  /*                                    ┃  ~L1  │  ~L2  ├───────┨   ┠───────┤  ~L2  │  ~L1  ┃                                    */
  /*                                    ┃       │       │  Del  ┃   ┃  Nbsp │       │       ┃                                    */
                                         MO(L_1),MO(L_2),KC_DEL ,   M(_NBSP),MO(L_2),MO(L_1)
  /*                                    ┗━━━━━━━┷━━━━━━━┷━━━━━━━┛   ┗━━━━━━━┷━━━━━━━┷━━━━━━━┛                                    */
  ),

[L_5] = ERGODOX_KEYMAP( // Layer 5 :
  /* ┏━━━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━━┓   ┏━━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━┯━━━━━━━━━┓ */
  /* ┃   Esc   │  & 1  │  é 2  │  " 3  │  ' 4  │  ( 5  │   ^L0  ┃   ┃  Pscr  │  - 6  │  è 7  │  _ 8  │  ç 9  │  à 0  │  Bspc   ┃ */
       KC_ESC  , KC_1  , KC_2  , KC_3  , KC_4  , KC_5  , TO(L_0),    KC_PSCR , KC_6  , KC_7  , KC_8  , KC_9  , KC_0  , KC_BSPC ,
  /* ┠─────────┼───────┼───────┼───────┼───────┼───────┼────────┨   ┠────────┼───────┼───────┼───────┼───────┼───────┼─────────┨ */
  /* ┃   Tab   │  a A  │  z Z  │  e E  │  r R  │  t T  │  Bkspc ┃   ┃   +    │  y Y  │  u U  │  i I  │  o O  │  p P  │   ^ ¨   ┃ */
       KC_TAB  , KC_Q  , KC_W  , KC_E  , KC_R  , KC_T  , KC_BSPC,    KC_PPLS , KC_Y  , KC_U  , KC_I  , KC_O  , KC_P  , KC_LBRC ,
  /* ┠─────────┼───────┼───────┼───────┼───────┼───────┤        ┃   ┠────────┼───────┼───────┼───────┼───────┼───────┼─────────┨ */
  /* ┃    #    │  q Q  │  s S  │  d D  │  f F  │  g G  ├────────┨   ┃        │  h H  │  j J  │  k K  │  l L  │  m M  │ Enter ⏎ ┃ */
        C_HTG  , KC_A  , KC_S  , KC_D  , KC_F  , KC_G  ,                       KC_H  , KC_J  , KC_K  , KC_L  ,KC_SCLN, KC_ENT  ,
  /* ┠─────────┼───────┼───────┼───────┼───────┼───────┤   Del  ┃   ┃   -    ├───────┼───────┼───────┼───────┼───────┼─────────┨ */
  /* ┃ LShft ⇧ │  w W  │  x X  │  c C  │  v V  │  b B  │        ┃   ┃        │  n N  │  , ?  │  ; .  │  : /  │  ! §  │ RShft ⇧ ┃ */
       KC_LSFT , KC_Z  , KC_X  , KC_C  , KC_V  , KC_B  , KC_DEL ,    KC_PMNS , KC_N  , KC_M  ,KC_COMM,KC_DOT ,KC_SLASH, KC_RSFT ,
  /* ┗━━━┱─────┴─┬─────┴─┬─────┴─┬─────┴─┬─────┴─┲━━━━━┷━━━━━━━━┛   ┗━━━━━━━━┷━━━━━┱─┴─────┬─┴─────┬─┴─────┬─┴─────┬─┴─────┲━━━┛ */
  /*     ┃ LCtl  │  LGui │  LAlt │  Bspc │  Del  ┃                                 ┃  Spc  │  RSft │  RAlt │  RGui │  RCtl ┃     */
          KC_LCTL,KC_LGUI,KC_LALT,KC_BSPC,KC_DEL ,                                  KC_SPC ,KC_RSFT,KC_RALT,KC_RGUI,KC_RCTL,
  /*     ┗━━━━━━━┷━━━━━━━┷━━━━━━━┷━━━━━━━┷━━━━━━━┛                                 ┗━━━━━━━┷━━━━━━━┷━━━━━━━┷━━━━━━━┷━━━━━━━┛     */
  /*                                            ┏━━━━━━━┯━━━━━━━┓   ┏━━━━━━━┯━━━━━━━┓                                            */
  /*                                            ┃I-Copy │I-Paste┃   ┃  <>   │ <> </>┃                                            */
                                               I_COPY  ,I_PASTE ,    M(_OTG),M(_ATG),
  /*                                    ┏━━━━━━━╃───────┼───────┨   ┠───────┼───────╄━━━━━━━┓                                    */
  /*                                    ┃       │       │ I-Cut ┃   ┃  </>  │       │       ┃                                    */
                                                          I_CUT ,    M(_CTG),
  /*                                    ┃  LAlt │  ~L2  ├───────┨   ┠───────┤  ~L2  │  ~L1  ┃                                    */
  /*                                    ┃       │       │  Del  ┃   ┃  Nbsp │       │       ┃                                    */
                                         KC_LALT,MO(L_2),KC_DEL ,   M(_NBSP),MO(L_2),MO(L_1)
  /*                                    ┗━━━━━━━┷━━━━━━━┷━━━━━━━┛   ┗━━━━━━━┷━━━━━━━┷━━━━━━━┛                                    */
  ),

};

const uint16_t PROGMEM fn_actions[] = {
};

const macro_t *action_get_macro(keyrecord_t *record, uint8_t id, uint8_t opt)
{
    // MACRODOWN only works in this function
    switch(id) {
        case _OTG: // Opening tag <>
            return MACRODOWN( \
                T(NUBS), D(RSFT), T(NUBS), U(RSFT), T(LEFT), \
                END);
        case _CTG: // Closing tag </>
            return MACRODOWN( \
                T(NUBS), D(RSFT), T(DOT), T(NUBS), U(RSFT), T(LEFT), \
                END);
        case _ATG: // Advanced tag <></>
            return MACRODOWN( \
                DOWN(KC_RCTL), DOWN(KC_LSFT), T(LEFT), UP(KC_LSFT), \
				T(X), UP(KC_RCTL), \
				T(NUBS), \
				DOWN(KC_RCTL), T(V), UP(KC_RCTL), \
				D(RSFT), T(NUBS), U(RSFT), \
				T(NUBS), \
				D(RSFT), T(DOT), U(RSFT), \
				DOWN(KC_RCTL), T(V), UP(KC_RCTL), \
				D(RSFT), T(NUBS), U(RSFT), \
				T(LEFT), DOWN(KC_RCTL), T(LEFT), UP(KC_RCTL), \
				T(LEFT), T(LEFT), \
                END);
			/*
            return MACRODOWN( \
                T(NUBS), D(RSFT), T(DOT), T(NUBS), U(RSFT), T(LEFT), \
                END);
            return MACRODOWN( \
                C_S_T(KC_LEFT), CTL_T(KC_X), \
                END);
			*/
        case _NBSP: // &nbsp;
            return MACRODOWN( \
                T(1), T(N), T(B), T(S), T(P), T(COMM), \
                END);
        case _HQF: // Olivier Pons / Django Expert / HQF Development
            return MACRODOWN(T(ENT), T(ENT), \
                DOWN(KC_LSFT), T(O), UP(KC_LSFT), \
                T(L), T(I), T(V), T(I), T(E), T(R), \
                T(SPC), \
                DOWN(KC_LSFT), T(P), UP(KC_LSFT), T(O), T(N), T(S), \
                T(SPC), \
                DOWN(KC_LSFT), T(DOT), UP(KC_LSFT), T(SPC), \
                DOWN(KC_LSFT), T(D), UP(KC_LSFT), \
                T(J), T(Q), T(N), T(G), T(O), \
                T(SPC), \
                DOWN(KC_LSFT), T(E), UP(KC_LSFT), \
                T(X), T(P), T(E), T(R), T(T), \
                T(SPC), \
                DOWN(KC_LSFT), T(DOT), UP(KC_LSFT), T(SPC), \
                DOWN(KC_LSFT), T(H), T(A), T(F), UP(KC_LSFT), T(SPC), \
                DOWN(KC_LSFT), T(D), UP(KC_LSFT), T(E), T(V), T(E), T(L), \
                T(O), T(P), T(SCLN), T(E), T(N), T(T), \
                END);
        case _MAIL: // olivier.pons@gmail.com
            return MACRODOWN(T(O), T(L), T(I), T(V), T(I), T(E), T(R), \
                DOWN(KC_LSFT), T(COMM), UP(KC_LSFT), \
                T(P), T(O), T(N), T(S), \
			    D(RALT), T(0), U(RALT), \
                T(G), T(SCLN), T(Q), T(I), T(L), \
                DOWN(KC_LSFT), T(COMM), UP(KC_LSFT), \
                T(C), T(O), T(SCLN), \
                END);
        case _HQF2: // Olivier Pons / Django Expert / HQF Development + site Web
            return MACRODOWN(T(ENT), T(ENT), \
                DOWN(KC_LSFT), T(O), UP(KC_LSFT), \
                T(L), T(I), T(V), T(I), T(E), T(R), \
                T(SPC), \
                DOWN(KC_LSFT), T(P), UP(KC_LSFT), T(O), T(N), T(S), \
                T(SPC), \
                DOWN(KC_LSFT), T(DOT), UP(KC_LSFT), T(SPC), \
                DOWN(KC_LSFT), T(D), UP(KC_LSFT), \
                T(J), T(Q), T(N), T(G), T(O), \
                T(SPC), \
                DOWN(KC_LSFT), T(E), UP(KC_LSFT), \
                T(X), T(P), T(E), T(R), T(T), \
                T(SPC), \
                DOWN(KC_LSFT), T(DOT), UP(KC_LSFT), T(SPC), \
                DOWN(KC_LSFT), T(H), T(A), T(F), UP(KC_LSFT), T(SPC), \
                DOWN(KC_LSFT), T(D), UP(KC_LSFT), T(E), T(V), T(E), T(L), \
                T(O), T(P), T(SCLN), T(E), T(N), T(T), \
				T(ENT), \
                T(H), T(T), T(T), T(P), T(S), T(DOT),
				DOWN(KC_LSFT), T(DOT), T(DOT), UP(KC_LSFT),
                T(O), T(L), T(I), T(V), T(I), T(E), T(R), \
                T(P), T(O), T(N), T(S), \
                DOWN(KC_LSFT), T(COMM), UP(KC_LSFT), \
                T(F), T(R), \
                END);
        case _GT: // > Greater than
            return MACRODOWN(D(RSFT), T(NUBS), U(RSFT), END);
        case _PPE: // | Pipe
            return MACRODOWN(D(RALT), T(6), U(RALT), END);
        case _BKS: // \ Backslash
            return MACRODOWN(D(RALT), T(8), U(RALT), END);
        case _LBK: // { Left bracket
            return MACRODOWN(D(RALT), T(4), U(RALT), END);
        case _RBK: // } Right bracket
            return MACRODOWN(D(RALT), T(EQL), U(RALT), END);
        case _SLH: // / Slash
            return MACRODOWN(D(RSFT), T(DOT), U(RSFT), END);
        case _HTG: // # Hashtag
            return MACRODOWN(D(RALT), T(3), U(RALT), END);
        case _OSB: // [ Opening Square bracket
            return MACRODOWN(D(RALT), T(5), U(RALT), END);
        case _CSB: // ] Closing Square bracket
            return MACRODOWN(D(RALT), T(MINS), U(RALT), END);
        case _ARB: // @ Arobase
            return MACRODOWN(D(RALT), T(0), U(RALT), END);
        case _TLD: // ~ Tilde
            return MACRODOWN(D(RALT), T(2), U(RALT), T(SPC), END);
        case _BQT: // ` Backquote
            return MACRODOWN(D(RALT), T(7), U(RALT), T(SPC), \
			    D(RALT), T(7), U(RALT), T(SPC), \
				T(LEFT), END);
            //return MACRODOWN(D(RALT), T(7), T(7), U(RALT), END);
        case _C_A: // â
            return MACRODOWN(T(LBRC), T(Q), END);
        case _C_E: // ê
            return MACRODOWN(T(LBRC), T(E), END);
        case _C_I: // î
            return MACRODOWN(T(LBRC), T(I), END);
        case _C_O: // ô
            return MACRODOWN(T(LBRC), T(O), END);
        case _C_U: // û
            return MACRODOWN(T(LBRC), T(U), END);
        case _XLT: // LCtrl - LAlt - ←
            return MACRODOWN(D(LCTL), D(LALT), T(LEFT), U(LALT), U(LCTL), END);
        case _XRT: // LCtrl - LAlt - →
            return MACRODOWN(D(LCTL), D(LALT), T(RIGHT), U(LALT), U(LCTL), END);
        case _L_0: // gg wp
            return MACRODOWN(T(ENT), \
                T(G), T(G), T(SPC), T(Z), T(P), \
                T(ENT), END);
        case _L_1: // gg wp!
            return MACRODOWN(T(ENT), \
                T(G), T(J), T(SLASH), \
                T(ENT), END);
        case _L_2: // sry i'm bad
            return MACRODOWN(T(ENT), \
                T(S), T(R), T(Y), T(SPC), T(I), T(4), T(SCLN), T(SPC), \
                T(B), T(Q), T(D), \
                T(ENT), END);
        case _L_3: // sry i'm very very bad
            return MACRODOWN(T(ENT), \
                T(S), T(R), T(Y), T(SPC), T(I), T(4), T(SCLN), T(SPC), \
                T(V), T(E), T(R), T(Y), T(SPC), T(V), T(E), T(R), T(Y), T(SPC), \
                T(B), T(Q), T(D), \
                T(ENT), END);
        case _L_4: // sry i'm trying my best
            return MACRODOWN(T(ENT), \
                T(S), T(R), T(Y), T(SPC), T(I), T(4), T(SCLN), T(SPC), \
                T(T), T(R), T(Y), T(I), T(N), T(G), T(SPC), \
                T(SCLN), T(Y), T(SPC), T(B), T(E), T(S), T(T), \
                T(ENT), END);
        case _L_5: // /mute all
            return MACRODOWN(T(ENT), \
                DOWN(KC_LSFT), T(DOT), UP(KC_LSFT), \
                T(SCLN), T(U), T(T), T(E), T(SPC), T(Q), T(L), T(L), \
                T(ENT), END);
        case _L_6: // please stop insult
            return MACRODOWN(T(ENT), \
                T(P), T(L), T(E), T(Q), T(S), T(E), T(SPC), \
                T(S), T(T), T(O), T(P), T(SPC), \
                T(I), T(N), T(S), T(U), T(L), T(T), \
                T(ENT), END);
        case _L_7: // sry i'm trying my best
            return MACRODOWN(T(ENT), \
                T(S), T(R), T(Y), T(SPC), T(I), T(4), T(SCLN), T(SPC), \
                T(T), T(R), T(Y), T(I), T(N), T(G), T(SPC), \
                T(SCLN), T(Y), T(SPC), T(B), T(E), T(S), T(T), \
                T(ENT), END);
        case _L_8: // be patient
            return MACRODOWN(T(ENT), \
                T(B), T(E), T(SPC), \
				T(P), T(Q), T(T), T(I), T(E), T(N), T(T), \
                T(ENT), END);
        case _L_9: // we'll win in the end
            return MACRODOWN(T(ENT), \
                T(Z), T(E), T(4), T(L), T(L), T(SPC), \
                T(Z), T(I), T(N), T(SPC), T(I), T(N), T(SPC), \
                T(T), T(H), T(E), T(SPC), T(E), T(N), T(D), \
                T(ENT), END);
        case _L10: // gj!
            return MACRODOWN(T(ENT), \
                T(G), T(J), T(SLASH), \
                T(ENT), END);
        case _L11: // wp!
            return MACRODOWN(T(ENT), \
                T(Z), T(P), T(SLASH), \
                T(ENT), END);
        case _L12: // gj wp!
            return MACRODOWN(T(ENT), \
                T(G), T(J), T(SPC), \
                T(Z), T(P), T(SLASH), \
                T(ENT), END);
        case _L13: // wow! you're amazing! best player ever!
            return MACRODOWN(T(ENT), \
                T(Z), T(O), T(Z), T(SLASH), T(SPC), \
                T(Y), T(O), T(U), T(4), T(R), T(E), T(SPC), \
                T(Q), T(SCLN), T(Q), T(W), T(I), T(N), T(G), T(SLASH), T(SPC), \
                T(B), T(E), T(S), T(T), T(SPC), \
                T(P), T(L), T(Q), T(Y), T(E), T(R), T(SPC), \
                T(E), T(V), T(E), T(R), T(SLASH), \
                T(ENT), END);
        case _L14: // you're so kind to play with me! thanks again!
            return MACRODOWN(T(ENT), \
                T(Y), T(O), T(U), T(4), T(R), T(E), T(SPC), \
                T(S), T(O), T(SPC), T(K), T(I), T(N), T(D), T(SPC), \
                T(T), T(O), T(SPC), T(P), T(L), T(Q), T(Y), T(SPC), \
                T(Z), T(I), T(T), T(H), T(SPC), T(SCLN), T(E), T(SPC), \
                T(T), T(H), T(Q), T(N), T(K), T(S), T(SPC), \
                T(Q), T(G), T(Q), T(I), T(N), T(SLASH), \
                T(ENT), END);
        case _L15: // mb sry...
            return MACRODOWN(T(ENT), \
                T(SCLN), T(B), T(SPC), T(S), T(R), T(Y), \
                DOWN(KC_LSFT), T(COMM), T(COMM), T(COMM), UP(KC_LSFT), \
                T(ENT), END);
        case _L16: // it's my fault sry
            return MACRODOWN(T(ENT), \
                T(I), T(T), T(4), T(S), T(SPC), \
                T(SCLN), T(Y), T(SPC), T(F), T(Q), T(U), T(L), T(T), T(SPC), \
                T(S), T(R), T(Y), \
                T(ENT), END);
        case _L17: // i'm so sorry...
            return MACRODOWN(T(ENT), \
                T(I), T(4), T(SCLN), T(SPC), \
                T(S), T(O), T(SPC), \
                T(S), T(O), T(SPC), T(S), T(O), T(R), T(R), T(Y), \
                DOWN(KC_LSFT), T(COMM), T(COMM), T(COMM), UP(KC_LSFT), \
                T(ENT), END);
        case _L18: // omg... i'm so bad, sorry...
            return MACRODOWN(T(ENT), \
                T(O), T(SCLN), T(G), T(SPC), \
                DOWN(KC_LSFT), T(COMM), T(COMM), T(COMM), UP(KC_LSFT), \
                T(I), T(4), T(SCLN), T(SPC), \
                T(S), T(O), T(SPC), T(B), T(Q), T(D), T(M), T(SPC), \
                T(S), T(O), T(SPC), T(S), T(R), T(Y), \
                DOWN(KC_LSFT), T(COMM), T(COMM), T(COMM), UP(KC_LSFT), \
                T(ENT), END);
        case _L19: // i'm so sry...
            return MACRODOWN(T(ENT), \
                T(I), T(4), T(SCLN), T(SPC), \
                T(S), T(O), T(SPC), T(S), T(R), T(Y), \
                DOWN(KC_LSFT), T(COMM), T(COMM), T(COMM), UP(KC_LSFT), \
                T(ENT), END);
    };
    return MACRO_NONE;
};

// Runs just one time when the keyboard initializes.
void matrix_init_user(void) {

};

// Runs constantly in the background, in a loop.
void matrix_scan_user(void) {

    uint8_t layer = biton32(layer_state);

    ergodox_board_led_off();
    ergodox_right_led_1_off();
    ergodox_right_led_2_off();
    ergodox_right_led_3_off();
    switch (layer) {
        case 1:
            ergodox_right_led_1_on();
            break;
        case 2:
            ergodox_right_led_2_on();
            break;
        default:
        // none
        break;
    }

};
